@@ -5,6 +5,8 @@ from emora._flows.backstory import backstory
 from emora._flows.competition import competition
 from emora._flows.house import house
 from emora._flows.reading import reading
+from emora._flows.world import world
+from emora._flows.family import family
 
 from _globals import PATHDIR
 from emora_stdm import CompositeDialogueFlow,DialogueFlow
@@ -18,7 +20,9 @@ flow_components = {
     'house': house,
     'reading': reading,
     'competition': competition,
-    'backstory': backstory
+    'backstory': backstory,
+    'world': world,
+    'family': family
 }
 
 cdf = CompositeDialogueFlow('root', 'recovery_from_failure', 'recovery_from_failure', DialogueFlow.Speaker.USER)
@@ -28,18 +32,21 @@ cdf.component('SYSTEM').knowledge_base().load_json_file(PATHDIR.replace('__***__
 for namespace, component in flow_components.items():
     cdf.add_component(component, namespace)
 
-cdf.add_system_transition('root', 'tournament:start', '')
-cdf.add_system_transition('root', 'school_new:start', '#GATE(schoolv:None)')
-cdf.add_system_transition('root', 'baby:start', '')
+# cdf.add_system_transition('root', 'tournament:start', '')
+# cdf.add_system_transition('root', 'school_new:start', '#GATE(schoolv:None)')
+# cdf.add_system_transition('root', 'baby:start', '')
 cdf.add_system_transition('root', 'house:start', '')
-cdf.add_system_transition('root', 'reading:start', '')
+# cdf.add_system_transition('root', 'reading:start', '')
+
+# cdf.add_system_transition('root', 'family:start->family:sibling', '', score=3.0)
+# cdf.add_system_transition('root', 'family:start->family:siblings', '', score=3.0)
 # cdf.add_system_transition('root', 'end', '`Oh, I have to go! Bye!`', score=-999)
 
-cdf.add_system_transition('life_opening', 'tournament:start', '')
-cdf.add_system_transition('life_opening', 'school_new:start', '#GATE(schoolv:None) #SET($schoolv=True)')
-cdf.add_system_transition('life_opening', 'baby:start', '')
+# cdf.add_system_transition('life_opening', 'tournament:start', '')
+# cdf.add_system_transition('life_opening', 'school_new:start', '#GATE(schoolv:None) #SET($schoolv=True)')
+# cdf.add_system_transition('life_opening', 'baby:start', '')
 cdf.add_system_transition('life_opening', 'house:start', '')
-cdf.add_system_transition('life_opening', 'reading:start', '')
+# cdf.add_system_transition('life_opening', 'reading:start', '')
 cdf.add_system_transition('life_opening', 'root', '', score=0.0)
 cdf.controller().update_state_settings('life_opening', system_multi_hop=True)
 
@@ -49,5 +56,5 @@ for component in cdf.components():
     component.add_macros({'CNC': emora_stdm.CheckNotComponent(cdf)})
 
 if __name__ == '__main__':
-    #emora.precache_transitions()
-    cdf.run(debugging=True)
\ No newline at end of file
+    #cdf.precache_transitions()
+    cdf.run(debugging=False)
\ No newline at end of file
