@@ -63,18 +63,29 @@ def get_jobs(filename):
     return jobs
 
 def get_dict_from_list(filename, append):
-    jobs = {}
+    d = {}
     with open(filename, "r") as f:
         for line in f:
             if line.isupper():
-                if append is not None:
+                if append is not None and len(append) > 0:
                     category = '_'+line.lower().strip()+" "+append
                 else:
                     category = '_' + line.lower().strip()
-                jobs[category] = []
+                d[category] = []
             elif len(line.strip()) > 0:
-                jobs[category].append(line.lower().strip())
-    return jobs
+                d[category].append(line.lower().strip())
+    return d
+
+def get_dict_from_list_without_underscore(filename):
+    d = {}
+    with open(filename, "r") as f:
+        for line in f:
+            if line.isupper():
+                category = line.lower().strip()
+                d[category] = []
+            elif len(line.strip()) > 0:
+                d[category].append(line.lower().strip())
+    return d
 
 class Ontology(dict):
 
@@ -94,11 +105,18 @@ class Ontology(dict):
         self["ontology"][parent] = func(arg)
 
     def merge_dict(self, parent, func, arg, arg2):
-        dict = func(arg, arg2)
-        self["ontology"][parent] = []
-        for key,value in dict.items():
-            self["ontology"][key] = value
-            self["ontology"][parent].append(key)
+        if arg2 is not None:
+            dict = func(arg, arg2)
+        else:
+            dict = func(arg)
+        if parent is not None:
+            self["ontology"][parent] = []
+            for key,value in dict.items():
+                self["ontology"][key] = handle_punc(value)
+                self["ontology"][parent].append(key)
+        else:
+            for key, value in dict.items():
+                self["ontology"][key] = handle_punc(value)
 
     def add_dict(self, d):
         for key,val in d.items():
@@ -107,7 +125,7 @@ class Ontology(dict):
     def add_expressions(self, e):
         self["expressions"] = e
 
-    def lemmatize(self):
+    def lemmatize(self, ignore):
         lemmatizer = nltk.stem.WordNetLemmatizer()
         lemmatizer.lemmatize('initialize')
         lemmatized_ontology = {}
@@ -116,6 +134,9 @@ class Ontology(dict):
             lemmatized_ontology[key] = {}
             ont = self[key]
             for k, l in ont.items():
+                if k in ignore:
+                    lemmatized_ontology[key][k] = l
+                    continue
                 lemmatized_ontology[key][k] = []
                 for e in l:
                     lemmas = set()
@@ -154,8 +175,12 @@ if __name__ == '__main__':
     ont.merge_dict("_job", get_dict_from_list, os.path.join(PATH,"jobs","job_list.txt"), "job")
     ont.merge_dict("_old_life stage", get_dict_from_list, os.path.join(PATH, "life_stage.txt"), "stage")
     ont.merge_dict("_school subject", get_dict_from_list, os.path.join(PATH, "school_subjects.txt"), "subject")
-    ont.merge_dict("_locations", get_dict_from_list, os.path.join(PATH, "locations.txt"), None)
+    ont.merge_dict("_locations", get_dict_from_list, os.path.join(PATH, "locations.txt"), "")
     ont.merge_dict("_names", get_dict_from_list, os.path.join(PATH, "names.txt"), "names")
+    ont.merge_dict("_adjectives", get_dict_from_list, os.path.join(PATH, "adjectives.txt"), "adj")
+    ont.merge_dict(None, get_dict_from_list_without_underscore, os.path.join(PATH, "adj_pos.txt"), None)
+    ont.merge_dict(None, get_dict_from_list_without_underscore, os.path.join(PATH, "adj_neg.txt"), None)
+
 
     # with open(os.path.join(PATH, "names.txt"), "r") as f:
     #     found = set()
@@ -172,7 +197,7 @@ if __name__ == '__main__':
     ont.add_dict(manual_ont["ontology"])
     ont.add_expressions(manual_ont["expressions"])
 
-    ont = Ontology(ont.lemmatize())
+    ont = Ontology(ont.lemmatize(ignore=['_positive adj','_negative adj']))
 
     #ont.display()
 
