@@ -210,11 +210,15 @@ class UnionMacro(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         sets = []
         for arg in args:
+            if isinstance(arg, str):
+                if arg[0] == '$':
+                    if arg[1:] in vars:
+                        arg = vars[arg[1:]]
+                    else:
+                        return set()
             if isinstance(arg, set):
                 sets.append(arg)
             if isinstance(arg, str):
-                if arg[0] == '$':
-                    arg = vars[arg[1:]]
                 sets.append({arg})
             elif isinstance(arg, list):
                 sets.append(set(arg))
@@ -224,11 +228,15 @@ class Intersection(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         sets = []
         for arg in args:
+            if isinstance(arg, str):
+                if arg[0] == '$':
+                    if arg[1:] in vars:
+                        arg = vars[arg[1:]]
+                    else:
+                        return set()
             if isinstance(arg, set):
                 sets.append(arg)
             if isinstance(arg, str):
-                if arg[0] == '$':
-                    arg = vars[arg[1:]]
                 sets.append({arg})
             elif isinstance(arg, list):
                 sets.append(set(arg))
@@ -269,39 +277,43 @@ def _get_terms(arg, operator, vars):
     return t1, t2
 
 def _term_op_term(arg, vars):
-    if '<=' in arg:
-        operator = '<='
-        t1, t2 = _get_terms(arg, operator, vars)
-        return t1 <= t2
-    elif '>=' in arg:
-        operator = '>='
-        t1, t2 = _get_terms(arg, operator, vars)
-        return t1 >= t2
-    elif '!=' in arg:
-        operator = '!='
-        t1, t2 = _get_terms(arg, operator, vars)
-        return t1 != t2
-    elif '<' in arg:
-        operator = '<'
-        t1, t2 = _get_terms(arg, operator, vars)
-        return t1 < t2
-    elif '>' in arg:
-        operator = '>'
-        t1, t2 = _get_terms(arg, operator, vars)
-        return t1 > t2
-    elif '=' in arg:
-        operator = '='
-        t1, t2 = _get_terms(arg, operator, vars)
-        return t1 == t2
+    if isinstance(arg, str):
+        if '<=' in arg:
+            operator = '<='
+            t1, t2 = _get_terms(arg, operator, vars)
+            return t1 <= t2
+        elif '>=' in arg:
+            operator = '>='
+            t1, t2 = _get_terms(arg, operator, vars)
+            return t1 >= t2
+        elif '!=' in arg:
+            operator = '!='
+            t1, t2 = _get_terms(arg, operator, vars)
+            return t1 != t2
+        elif '<' in arg:
+            operator = '<'
+            t1, t2 = _get_terms(arg, operator, vars)
+            return t1 < t2
+        elif '>' in arg:
+            operator = '>'
+            t1, t2 = _get_terms(arg, operator, vars)
+            return t1 > t2
+        elif '=' in arg:
+            operator = '='
+            t1, t2 = _get_terms(arg, operator, vars)
+            return t1 == t2
+        elif '$' == arg[0]:
+            return bool(vars[arg[1:]])
+        else:
+            return None
     else:
-        return False
+        return bool(arg)
 
 class SetVars(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         for arg in args:
             var, val = _assignment_to_var_val(arg)
             vars[var] = val
-        return None
 
 class CheckVarsConjunction(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
@@ -947,6 +959,37 @@ class CheckNotComponent(Macro):
             return False
         return True
 
+class ExtractList(Macro):
+    """
+    Extracts all matching phrases from user utterance, given ontology categories or phrase literals, and
+    stores them in the provided variable name as a list
+
+    args:
+        [0] - variable name
+        [1 - n] - ontology categories and phrase literals
+    """
+
+    def __init__(self, kb):
+        self.onte = ONTE(kb)
+
+    def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
+        var = args[0]
+        if var not in vars:
+            vars[var] = set()
+        # find matches
+        matches = self.onte(ngrams, None, args[1:])
+        matches.update({arg for arg in args[1:] if arg in ngrams})
+        vars[var].update(matches)
+        return matches
+
+class Contains(Macro):
+
+    def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
+        if isinstance(args[1], str):
+            return args[0] in args[1:]
+        else:
+            return args[0] in args[1]
+
 
 _conjunction_macro = CheckVarsConjunction()
 
@@ -974,30 +1017,9 @@ macros_common_dict = {
     'IF': _conjunction_macro,
     'ANY': CheckVarsDisjunction(),
     'ISP': IsPlural(),
+    'IN': Contains()
 }
 
-class ExtractList(Macro):
-    """
-    Extracts all matching phrases from user utterance, given ontology categories or phrase literals, and
-    stores them in the provided variable name as a list
-
-    args:
-        [0] - variable name
-        [1 - n] - ontology categories and phrase literals
-    """
-
-    def __init__(self, kb):
-        self.onte = ONTE(kb)
-
-    def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
-        var = args[0]
-        if var not in vars:
-            vars[var] = set()
-        # find matches
-        matches = self.onte(ngrams, None, args[1:])
-        matches.update({arg for arg in args[1:] if arg in ngrams})
-        vars[var].update(matches)
-
 
 
 
